@@ -1,7 +1,15 @@
+import re
+
 import pytest
+
+from decaptcha import __version__
 from decaptcha.notarobot import DispersiveGround
 
 
+def test_version():
+    assert re.search("^\d+[.]\d+[.]\d+$", __version__).group() is not None
+
+
 @pytest.fixture()
 def bot():
     return DispersiveGround()
